@@ -16,6 +16,17 @@ from PaperCrawlerUtil.office_util import *
 import pymysql
 
 
+class Conditions(dict):
+
+    relations = ["=", ">", ">=", "<", "<=", "in", "not in"]
+
+    def __init__(self) -> None:
+        super().__init__()
+
+    def add_condition(self, key: str, value: str, relation: str = "="):
+        self.__setitem__((key, value), relation)
+
+
 class DB_util(object):
 
     def __init__(self, **db_conf) -> None:
@@ -43,22 +54,23 @@ class DB_util(object):
         self.port = self.ssl.local_bind_port if check_ssl else db_conf.get("port")
         self.db_database = db_conf.get("db_database") if db_conf.get("db_database") is not None else "research"
         self.db_table = db_conf.get("db_table") if db_conf.get("db_table") is not None else "record_result"
-        self.db_field = db_conf.get("db_field") if db_conf.get("db_field") is not None \
-            else ["id", "file_execute", "execute_time", "finish_time", "result", "args", "other", "delete_flag"]
         self.db_type = db_conf.get("db_type") if db_conf.get("db_type") is not None else "mysql"
-
         self.ignore_error = db_conf.get("ignore_error") if db_conf.get("ignore_error") is not None else True
         try:
             self.create_db_conn()
             self.cursor = self.conn.cursor()
         except Exception as e:
             log("链接数据库失败，请修改配置，云服务器请配置ssl：{}".format(e))
+        self.show_sql = db_conf.get("show_sql") if db_conf.get("show_sql") is not None else True
+        self.db_field = self.query_table_field()
 
     def generate_sql(self, kvs: Dict = None, op_type: str = OP_TYPE[3],
                      condition: Dict[Tuple[str, int or float or str or Tuple], str] = None,
-                     limit: int = 100) -> str:
+                     limit: int = 100, offset: int = 0, field_quota: bool = True) -> str:
         """
         根据给定的值生成简单的sql，其中select语句最难生成，因此只能是给个参考，慎用本方法生成select语句
+        :param field_quota: 是否需要在查询时，给字段名加引号
+        :param offset: 分页查询时，从0开始的偏移量
         :param condition:键值对，键是元组，长度为两个元素，值是条件参数，例如：
         {("dass", 231): "="}，代码会转换为“dass” = 231 作为条件加入where语句
         :param limit:select 语句中防止查询过大，默认100
@@ -81,9 +93,14 @@ class DB_util(object):
         condition_clause = "WHERE "
         if op_type == OP_TYPE[3] and (kvs is None or len(kvs) == 0):
             fields = "*"
+        elif op_type == DELETE:
+            fields = ""
         else:
             for kv in kvs.items():
-                fields.append("`" + str(kv[0]) + "`")
+                if field_quota:
+                    fields.append("`" + str(kv[0]) + "`")
+                else:
+                    fields.append(str(kv[0]))
                 t = type(kv[1])
                 if t == int or t == float:
                     values.append(str(kv[1]))
@@ -107,11 +124,11 @@ class DB_util(object):
                     condition_clause = condition_clause + " AND "
                 count = count + 1
         if op_type not in OP_TYPE:
-            op_type = OP_TYPE[3]
-        if op_type == OP_TYPE[0]:
+            op_type = SELECT
+        if op_type == INSERT:
             sql = "INSERT INTO `" + self.db_database + "`.`" + self.db_table + "` ({})" + " VALUES ({});"
             sql = sql.format(", ".join(fields), ", ".join(values))
-        elif op_type == OP_TYPE[1]:
+        elif op_type == UPDATE:
             sql = "UPDATE `" + self.db_database + "`.`" + self.db_table + "` SET {} {};"
             modify = ""
             for i in range(len(fields)):
@@ -119,13 +136,13 @@ class DB_util(object):
                 if i < len(fields) - 1:
                     modify = modify + ", "
             sql = sql.format(modify, condition_clause)
-        elif op_type == OP_TYPE[2]:
+        elif op_type == DELETE:
             sql = "DELETE FROM `" + self.db_database + "`.`" + self.db_table + "` {};"
             sql = sql.format(condition_clause)
-        elif op_type == OP_TYPE[3]:
+        elif op_type == SELECT:
             sql = "SELECT" + " {} ".format(
-                ", ".join(fields)) + "FROM `" + self.db_database + "`.`" + self.db_table + "` {} LIMIT {};". \
-                      format(condition_clause, str(limit))
+                ", ".join(fields)) + "FROM `" + self.db_database + "`.`" + self.db_table + "` {} LIMIT {} OFFSET {};". \
+                      format(condition_clause, str(limit), str(offset))
         return sql
 
     def create_db_conn(self):
@@ -143,13 +160,26 @@ class DB_util(object):
         self.conn = connection
         self.conn.autocommit(True)
 
+    def query_table_field(self):
+        """
+        查询表中所有的字段名称
+        :return:
+        """
+        sql = "select COLUMN_NAME from information_schema.COLUMNS where table_name = '{}';".format(self.db_table)
+        if self.execute(sql):
+            return [i[0] for i in self.cursor.fetchall()]
+        else:
+            return []
     def execute(self, sql: str) -> bool:
         """
         内部方法，执行sql
         也可以执行用户自定义的sql，比如利用建表时默认的四个默认列记录数据等
+        :param show_sql: 是否在执行时，显示sql
         :param sql: 待执行的sql
         :return:
         """
+        if self.show_sql:
+            log(sql)
         try:
             self.cursor.execute(sql)
             return True
@@ -159,32 +189,137 @@ class DB_util(object):
                 write_file(local_path_generate("", "record_error.log"), mode="a+", string=sql + "\n")
             return False
 
-    def select_one(self, condition: Dict) -> List:
+    def select(self, condition: Dict = None, kvs: Dict or List = None, format: str = "one") -> List:
         """
         查询一个记录
-        :param condition:条件字典，形如{("a", "b") : "="} 即 where a = b，或者{"a":"b"},后台会自动将后一种形式转换为前一种，
-        但是，二者的关系只能是"="，即后面一种形式是前一种形式的特定情况简化版。
+        :param format: 查询的规模，"one"，代表查询一个记录， "all"代表查询所有
+        :param kvs: 要查询的字段，可以接受字典，列表，其中字典的value并没有使用，只使用key
+        :param condition:条件字典，形如{("a", "b") : "="} 即 where a = b
         :return:
         """
-        sql = self.generate_sql(condition=condition, op_type=SELECT)
+        if type(kvs) == list:
+            t = {}
+            for i in kvs:
+                t[i] = ""
+            kvs = t
+        sql = self.generate_sql(condition=condition, op_type=SELECT, kvs=kvs)
         if self.execute(sql):
-            return self.cursor.fetchone()
+            return self.cursor.fetchone() if format == "one" else self.cursor.fetchall()
         else:
             return []
 
-    def select_page(self, condition: Dict, limit: int = 100) -> List[List]:
-        return []
+    def select_page(self, condition: Conditions = None, page: int = 100, page_no: int = 0) -> List[List]:
+        """
+        分页查找
+        :param condition:条件
+        :param page:页面大小
+        :param page_no: 页面号
+        :return:
+        """
+        res = []
+        if condition is None:
+            condition = Conditions()
+        sql = self.generate_sql(kvs={"count(*) ": ""}, op_type=SELECT, condition=condition, field_quota=False)
+        sum_page = None
+        if self.execute(sql):
+            sum_page = self.cursor.fetchone()[0]
+            sum_page = int(sum_page / page) + 1
+        else:
+            sum_page = 0
+        sql = self.generate_sql(op_type=SELECT, limit=page, offset=page_no * page, condition=condition)
+        if self.execute(sql):
+            return self.cursor.fetchall(), sum_page
+        else:
+            return [], 0
 
     def insert_one(self, kvs: Dict or List) -> bool:
+        """
+        插入一条记录
+        :param kvs:需要插入的字段以及对应的值，当为list时，要求值与表所有字段对应
+        :return:
+        """
+        if type(kvs) == list and len(kvs) != len(self.db_field):
+            log("when input has only list, the len of list must equal with table fileds")
+            return False
+        elif type(kvs) == list and len(kvs) == len(self.db_field):
+            t = {}
+            for i in range(len(self.db_field)):
+                t[self.db_field[i]] = kvs[i]
+            kvs = t
+        sql = self.generate_sql(kvs=kvs, op_type=INSERT)
+        if self.execute(sql):
+            return True
+        else:
+            return False
+
+    def update(self, condition: Conditions, kvs: Dict or List) -> bool:
+        """
+        更新记录
+        :param condition: 条件
+        :param kvs: 需要插入的字段以及对应的值，当为list时，要求值与表所有字段对应
+        :return:
+        """
+        if type(kvs) == list and len(kvs) != len(self.db_field):
+            log("when input has only list, the len of list must equal with table fileds")
+            return False
+        elif type(kvs) == list and len(kvs) == len(self.db_field):
+            t = {}
+            for i in range(len(self.db_field)):
+                t[self.db_field[i]] = kvs[i]
+            kvs = t
+        sql = self.generate_sql(kvs=kvs, op_type=UPDATE, condition=condition)
+        if self.execute(sql):
+            return True
+        else:
+            return False
+
+    def delete(self, condition: Conditions) -> bool:
+        """
+        删除记录
+        :param condition: 条件
+        :return:
+        """
+        sql = self.generate_sql(op_type=DELETE, condition=condition)
+        if self.execute(sql):
+            return True
+        else:
+            return False
         return True
 
-    def update(self, condition: Dict) -> bool:
-        return True
-
-    def delete(self, condition: Dict) -> bool:
-        return True
-
-    def export(self, condition: Dict) -> bool:
+    def export(self, condition: Conditions, file_type: str = "csv", export_path: str = "",
+               process: Callable[[List[str]], List] = None, field_name: List = None) -> bool:
+        """
+        导出文件
+        :param field_name: 数据表中列的名称，默认为空
+        :param process: 导出时对于列数据的处理，传入每行数据，输出改变后的每一行数据
+        :param export_path: 导出文件的地址，默认为当前目录
+        :param condition:条件
+        :param file_type: 导出的类型，包括["csv", "xls"]
+        :return:
+        """
+        if field_name is None:
+            field_name = []
+        res = list(self.select(condition, format="all"))
+        if process is not None:
+            for i in range(len(res)):
+                try:
+                    res[i] = process(res[i])
+                except Exception as e:
+                    log("处理数据程序错误：{}".format(e), print_file=sys.stderr)
+        log("成功导出数据{}条".format(len(res)))
+        res.insert(0, field_name)
+        export_path = export_path if len(export_path) > 0 else \
+            local_path_generate("", suffix=".csv" if file_type == "csv" else ".xls")
+        try:
+            if file_type == "csv":
+                csv = CsvProcess()
+                csv.write_csv(res, write_path=export_path)
+            else:
+                ExcelProcess().write_excel(res, path=export_path)
+            return True
+        except Exception as e:
+            log("导出失败：{}".format(e))
+            return False
         return True
 
     def __del__(self):
@@ -459,6 +594,8 @@ class ResearchRecord(object):
         condition_clause = "WHERE "
         if op_type == OP_TYPE[3] and (kvs is None or len(kvs) == 0):
             fields = "*"
+        elif op_type == DELETE:
+            fields = ""
         else:
             for kv in kvs.items():
                 fields.append("`" + str(kv[0]) + "`")
@@ -616,3 +753,4 @@ class ResearchRecord(object):
 if __name__ == "__main__":
     basic_config(logs_style=LOG_STYLE_PRINT)
 
+
